﻿using System.Windows;
using System.Windows.Controls;
using CommonServiceLocator.NinjectAdapter;
using Microsoft.Practices.ServiceLocation;
using Ninject;
using Ninject.Extensions.Conventions;
using ViewModelLocation.ViewModels;

namespace ViewModelLocation
{
    public partial class App : Application
    {
        public App()
        {
            this.Startup += this.Application_Startup;
            this.UnhandledException += this.Application_UnhandledException;

            InitializeComponent();

            SetupServiceLocation();
        }

        private void SetupServiceLocation()
        {
            var ninjectKernel = new StandardKernel();

            ninjectKernel.Scan(x =>
                                   {
                                       x.FromAssemblyContaining<HomeViewModel>();
                                       x.BindWithDefaultConventions();
                                   });

            var ninjectServiceLocator = new NinjectServiceLocator(ninjectKernel);
            ServiceLocator.SetLocatorProvider(() => ninjectServiceLocator);
        }


        private void Application_Startup(object sender, StartupEventArgs e)
        {
            this.RootVisual = new MainPage();
        }

        private void Application_UnhandledException(object sender, ApplicationUnhandledExceptionEventArgs e)
        {
            // If the app is running outside of the debugger then report the exception using
            // a ChildWindow control.
            if (!System.Diagnostics.Debugger.IsAttached)
            {
                // NOTE: This will allow the application to continue running after an exception has been thrown
                // but not handled. 
                // For production applications this error handling should be replaced with something that will 
                // report the error to the website and stop the application.
                e.Handled = true;
                ChildWindow errorWin = new ErrorWindow(e.ExceptionObject);
                errorWin.Show();
            }
        }
    }
}