using System;
using System.Linq;

namespace ViewModelLocation.MVVM
{
    public class ViewModelLocator
    {
        public Type GetViewModelTypeForView(Type viewType)
        {
            var viewModelName = ResolveViewModelName(viewType.Name).ToLower();

            var foundViewModelType = (from type in viewType.Assembly.GetExportedTypes()
                                      where viewModelName.Equals(type.Name.ToLower())
                                      select type).FirstOrDefault();

            if (foundViewModelType == null) { throw new ViewModelTypeNotResolvedException(viewModelName, viewType); }

            return foundViewModelType;
        }


        private string ResolveViewModelName(string viewTypeName)
        {
            var asLowerViewTypeName = viewTypeName.ToLower();

            // check to see if the view ends w/ "View"
            if (asLowerViewTypeName.EndsWith("view"))
            {
                return asLowerViewTypeName.Replace("view", "ViewModel");
            }

            return string.Concat(viewTypeName, "ViewModel");
        }
    }
}