using System;

namespace ViewModelLocation.MVVM
{
    public class ViewModelTypeNotResolvedException : Exception
    {
        public string ViewModelName { get; set; }
        public Type ViewName { get; set; }

        // Commented this out because i do not want to be able to create this without the VMName or the VName
        //public ViewModelTypeNotResolvedException() {}

        /// <summary>
        /// Will build an instance of the exception and push in a default message based on the viewModelname and view properties.
        /// *** This is the lazy way to create the message ***
        /// </summary>
        /// <param name="viewModelName">The name of the viewModel which was not able to be created or found</param>
        /// <param name="view">The type for the view we were trying to bind the VM to</param>
        public ViewModelTypeNotResolvedException(string viewModelName, Type view)
            : base(string.Format("When trying to resolve the view model {0} it was not found in the same assembly as the view {1}", viewModelName, view.Name))
        {
            ViewModelName = viewModelName;
            ViewName = view;
        }

        /// <summary>
        /// Will build an instance of the exception
        /// </summary>
        /// <param name="viewModelName">The name of the viewModel which was not able to be created or found</param>
        /// <param name="view">The type for the view we were trying to bind the VM to</param>
        /// <param name="message"></param>
        public ViewModelTypeNotResolvedException(string viewModelName, Type view, string message)
            : base(message)
        {
            ViewModelName = viewModelName;
            ViewName = view;
        }

        /// <summary>
        /// Will build an instance of the exception
        /// </summary>
        /// <param name="viewModelName">The name of the viewModel which was not able to be created or found</param>
        /// <param name="view">The type for the view we were trying to bind the VM to</param>
        /// <param name="message"></param>
        /// <param name="innerException"></param>
        public ViewModelTypeNotResolvedException(string viewModelName, Type view, string message, Exception innerException)
            : base(message, innerException)
        {
            ViewModelName = viewModelName;
            ViewName = view;
        }
    }
}